@@ -13,15 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-# @author: Stéphane Albert
-#
-from oslo import i18n  # noqa
+import oslo_i18n as i18n  # noqa
 
 _translators = i18n.TranslatorFactory(domain='cloudkitty')
-i18n.enable_lazy()
 
 _ = _translators.primary
-_LI = _translators.log_info
-_LW = _translators.log_warning
-_LE = _translators.log_error
-_LC = _translators.log_critical
